@@ -44,10 +44,11 @@
 
 /**
  * SECTION:element-rdtmanager
- * @title: rdtmanager
  * @see_also: GstRtspSrc
  *
  * A simple RTP session manager used internally by rtspsrc.
+ *
+ * Last reviewed on 2006-06-20 (0.10.4)
  */
 
 /* #define HAVE_RTCP */
@@ -337,8 +338,6 @@ free_session (GstRDTManagerSession * session)
 
 #define gst_rdt_manager_parent_class parent_class
 G_DEFINE_TYPE (GstRDTManager, gst_rdt_manager, GST_TYPE_ELEMENT);
-GST_ELEMENT_REGISTER_DEFINE (rdtmanager, "rdtmanager",
-    GST_RANK_NONE, GST_TYPE_RDT_MANAGER);
 
 /* BOXED:UINT,UINT */
 #define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
@@ -520,15 +519,15 @@ gst_rdt_manager_class_init (GstRDTManagerClass * g_class)
       GST_DEBUG_FUNCPTR (gst_rdt_manager_release_pad);
 
   /* sink pads */
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_rdt_manager_recv_rtp_sink_template);
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_rdt_manager_recv_rtcp_sink_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_rdt_manager_recv_rtp_sink_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_rdt_manager_recv_rtcp_sink_template));
   /* src pads */
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_rdt_manager_recv_rtp_src_template);
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_rdt_manager_rtcp_src_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_rdt_manager_recv_rtp_src_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_rdt_manager_rtcp_src_template));
 
   gst_element_class_set_static_metadata (gstelement_class, "RTP Decoder",
       "Codec/Parser/Network",
@@ -555,7 +554,6 @@ gst_rdt_manager_finalize (GObject * object)
 
   g_slist_foreach (rdtmanager->sessions, (GFunc) free_session, NULL);
   g_slist_free (rdtmanager->sessions);
-  g_clear_object (&rdtmanager->provided_clock);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -1369,3 +1367,10 @@ static void
 gst_rdt_manager_release_pad (GstElement * element, GstPad * pad)
 {
 }
+
+gboolean
+gst_rdt_manager_plugin_init (GstPlugin * plugin)
+{
+  return gst_element_register (plugin, "rdtmanager",
+      GST_RANK_NONE, GST_TYPE_RDT_MANAGER);
+}
